@@ -32,6 +32,7 @@
 #' @keywords utilities
 #' @seealso \code{\link{ReadCrossRef}}, \code{\link{BibEntry}}, \code{\link{open.BibEntry}}
 #' @importFrom plyr llply progress_text
+#' @importFrom utils flush.console
 ReadPDFs <- function (path, .enc = 'UTF-8', recursive = TRUE, use.crossref = TRUE,
                       use.metadata = TRUE, progress = FALSE) {
   if (!nzchar(Sys.which("pdfinfo")))
@@ -41,7 +42,7 @@ ReadPDFs <- function (path, .enc = 'UTF-8', recursive = TRUE, use.crossref = TRU
       stop("Specified path does not exist")
   files <- list.files(path, pattern = '.pdf$', full.names = TRUE, recursive = recursive)
   if (!length(files)){  # check if directory or file specified
-      if (!grepl("[.]pdf$", path))
+      if (!grepl("[.]pdf$", path, useBytes = TRUE))
           stop(gettextf("%s must be a valid path containing PDFs or a file name ending in %s",
                         sQuote("path"), dQuote(".pdf"), domain = NA))
     files <- path
@@ -150,7 +151,7 @@ ReadPDFs <- function (path, .enc = 'UTF-8', recursive = TRUE, use.crossref = TRU
   res <- c(resJSTOR, res)
   if (length(res)){
     res <- withCallingHandlers( lapply(res, MakeBibEntry, to.person = FALSE), warning = function(w){
-      if( any( grepl("recycled", w$message) ) )
+      if( any( grepl("recycled", w$message, useBytes = TRUE) ) )
         invokeRestart( "muffleWarning" )
       })
     res <- MakeCitationList(res)
@@ -174,6 +175,6 @@ ReadPDFs <- function (path, .enc = 'UTF-8', recursive = TRUE, use.crossref = TRU
         res[[ind[i]]]$doi <- comb.doi[ind2[i]]
     }
   }
-
+  res <- MakeKeysUnique(res)
   return(res)
 }
